* Figure 3.1 
clear all 
set more off

use OECD5w_RusChi, clear // 2005 World Value Survey merged with OECD country data

* Label variables that aren't already labeled: 
lab var dchild_ind  "Praising independence"
lab var dchild_imag "Praising imagination"
lab var dchild_hw   "Praising hard work"
lab var dchild_obed "Praising obedience"
lab define yn_lab 0 "No" 1 "Yes"
lab values dchild_ind dchild_imag dchild_hw dchild_obed yn_lab
lab var gini "Gini times 100"

*Important criteria: Only considered individuals stating at least one of the four variables 
drop if dchild_imag==0 & dchild_ind==0 & dchild_hw==0 & dchild_obed==0

*Calculate the mean response for each country: 
collapse country_num dchild_imag dchild_ind dchild_hw dchild_obed wave year dec9_1 gini gini_oecd, by (country) 
 
* Manually add Gini for China and Russia 
replace gini_oecd = 0.425  if country == "China"
replace gini_oecd = 0.415 if country == "Russia" 

*Multiply by 100 to have correct y axis
replace dchild_ind=100*dchild_ind
replace dchild_imag=100*dchild_imag
replace dchild_hw=100*dchild_hw
replace dchild_obed=100*dchild_obed

*Final version: independence
twoway (scatter dchild_ind gini_oecd, mlabel(country) color(black) mlabcolor(black)) (lfit dchild_ind gini_oecd, lcolor(gray)), legend(off) xtitle("Income Inequality (Gini Coefficient)") ytitle("Parents Praising Independence (%)") ylabel(30 (10) 100) xlabel(0.25 (.05) 0.45) graphregion(color(white))
graph save "gini_ind_w5_fv.gph", replace

*Final version: imagination
twoway (scatter dchild_imag gini_oecd, mlabel(country) color(black) mlabcolor(black)) (lfit dchild_imag gini_oecd, lcolor(gray)), legend(off)  xtitle("Income Inequality (Gini Coefficient)") ytitle("Parents Praising Imagination (%)") ylabel(10 (10) 70) xlabel(0.25 (.05) 0.45) graphregion(color(white))
graph save "gini_imag_w5_fv.gph", replace

*Final version: hard work
twoway (scatter dchild_hw gini_oecd, mlabel(country) color(black) mlabcolor(black)) (lfit dchild_hw gini_oecd, lcolor(gray)), legend(off) xtitle("Income Inequality (Gini Coefficient)") ytitle("Parents Praising Hard Work (%)") ylabel(10 (10) 95) xlabel(0.25 (.05) 0.45) graphregion(color(white))
graph save "gini_hw_w5_fv.gph", replace

*Final version: obedience
twoway (scatter dchild_obed gini_oecd, mlabel(country) color(black) mlabcolor(black)) (lfit dchild_obed gini_oecd, lcolor(gray)), legend(off) xtitle("Income Inequality (Gini Coefficient)") ytitle("Parents Praising Obedience (%)") ylabel(5 (10) 50) xlabel(0.25 (.05) 0.45) graphregion(color(white))
graph save "gini_obed_w5_fv.gph", replace

* Combine the graphs: 
graph combine "gini_imag_w5_fv.gph" "gini_ind_w5_fv.gph" "gini_hw_w5_fv.gph" , rows(1) altshrink graphregion(color(white)) ///
ysize(5) xsize(15) saving("Figure3_1_fv.gph",replace)

