* Figure 3.2 
clear all
set more off

use WVS_OECD, clear // World value survey, multiple years, with OECD data on 90/10 inequality

/* The PERMISSIVE, AUTHORITATIVE, AUTHORITARIAN variables were generated from
the question asking parent to praise obedience, imagination, hark work, independence
*PERMISSIVE: Praising Imagination or Independe (or both), No Hard Work No Obedience 
*AUTHORITATIVE: Praising Hard Work, No Obedience
*AUTHORITARIAN: Praising Obedience
*/

* Compute mean of each parenting style and of the 90/10 ratio by country-year
collapse permissive authoritative authoritarian dec9_1, by(country country_num year wave country3l_wave)

* Label the countries: 
gen country_code="AUS" if country_num==36
replace country_code="CAN" if country_num==124
replace country_code="FIN" if country_num==246
replace country_code="FRA" if country_num==250
replace country_code="DEU" if country_num==276
replace country_code="ITA" if country_num==380
replace country_code="JPN" if country_num==392
replace country_code="NLD" if country_num==528
replace country_code="NZL" if country_num==554
replace country_code="NOR" if country_num==578
replace country_code="ESP" if country_num==724
replace country_code="SWE" if country_num==752
replace country_code="CHE" if country_num==756
replace country_code="TUR" if country_num==792
replace country_code="GBR" if country_num==826
replace country_code="USA" if country_num==840

* Create a country-year id:
egen country_year=concat(country_code year)

* Average values across survey waves for each country
bysort country: egen average_perm=mean(permissive) if dec9_1!=.
bysort country: egen average_av=mean(authoritative) if dec9_1!=.
bysort country: egen average_an=mean(authoritarian) if dec9_1!=.
bysort country: egen average_dec91=mean(dec9_1)

* multiply by 100 to have percentage on the Y-Axis
replace  average_perm=100*average_perm
replace  average_av=100*average_av
replace  average_an=100*average_an

* Permissive:
twoway (scatter average_perm average_dec91, color(black) mlabcolor(black) mlabel(country) mlabsize(vsmall) mlabposition(1)) (lfit average_perm average_dec91, color(gray)), ///
legend(off) xtitle("Income Inequality (Ratio Top 10%-to-Bottom 10% Earnings)", size(small)) ytitle("Permissive Parents (%)") /// 
ylabel(5 (10) 85) xscale(r(1.8 5.2)) xlabel(2 (1) 5) graphregion(color(white))
graph save "permissive_fv.gph", replace

* Authoritative
twoway (scatter average_av average_dec91, color(black) mlabcolor(black) mlabel(country) mlabsize(vsmall) mlabposition(1)) (lfit average_av average_dec91, color(gray)), /// 
legend(off) xtitle("Income Inequality (Ratio Top 10%-to-Bottom 10% Earnings)", size(small)) ytitle("Authoritative Parents (%)") ///
ylabel(5 (10) 85) xscale(r(1.8 5.2)) xlabel(2 (1) 5) graphregion(color(white))
graph save "authoritative_fv.gph", replace

* Authoritarian
twoway (scatter average_an average_dec91, color(black) mlabcolor(black) mlabel(country) mlabsize(vsmall) mlabposition(1)) (lfit average_an average_dec91, color(gray)), ///
legend(off) xtitle("Income Inequality (Ratio Top 10%-to-Bottom 10% Earnings)", size(small)) ytitle("Authoritarian Parents (%)") /// 
ylabel(5 (10) 85) xscale(r(1.8 5.2)) xlabel(2 (1) 5) graphregion(color(white))
graph save "authoritarian_fv.gph", replace

* Combine the graph 
graph combine "permissive_fv.gph" "authoritative_fv.gph" "authoritarian_fv.gph" , rows(1) altshrink graphregion(color(white)) ///
ysize(5) xsize(15) saving("Figure3_2_fv.gph",replace)
