* Figure 3.4
clear all
set more off

use WVS_TAX, clear 
/* World value survey, multiple years, with Andrew Young School of 
Policy Studies data on tax progressivity for each country
*/

/* The PERMISSIVE, AUTHORITATIVE, AUTHORITARIAN variables were generated from
the question asking parent to praise obedience, imagination, hark work, independence
*PERMISSIVE: Praising Imagination or Independe (or both), No Hard Work No Obedience 
*AUTHORITATIVE: Praising Hard Work, No Obedience
*AUTHORITARIAN: Praising Obedience
*/

* Calculate means of each variable by country-year-wave
collapse permissive authoritative authoritarian MRP_all, by(country year wave country3l_wave)

* Average over waves
bysort country: egen average_perm=mean(permissive)
bysort country: egen average_av=mean(authoritative)
bysort country: egen average_an=mean(authoritarian)
bysort country: egen average_MRP=mean(MRP_all)
 
 * multiply by 100 to have percentage in the Y-Axis
 replace average_perm=100*average_perm
 replace average_av=100*average_av
 replace average_an=100*average_an
 
*Permissive
twoway (scatter average_perm average_MRP,  color(black) mlabcolor(black)  mlabel(country) mlabsize(vsmall) mlabposition(1)) (lfit average_perm average_MRP, color(black)), ///
legend(off) xtitle("Tax Progressivity (USA=1)") ytitle("Permissive parents (%)")  ///
ylabel(5 (10) 85) xscale(r(0.03 0.12)) graphregion(color(white)) xticks(0.0410313 (0.02) 0.1210313) xlabel(none) // xlabel(0.0410313 (0.02) 0.1210313) 
graph save "Tax_AvPermissive_fv.gph", replace

*Authoritative
twoway (scatter average_av average_MRP, color(black) mlabcolor(black)  mlabel(country) mlabsize(vsmall) mlabposition(1)) (lfit average_av average_MRP, color(black)), ///
legend(off) xtitle("Tax Progressivity (USA=1)") ytitle("Authoritative parents (%)")  ///
ylabel(5 (10) 85) xscale(r(0.03 0.12)) graphregion(color(white)) xticks(0.0410313 (0.02) 0.1210313) xlabel(none) // xlabel(0.0410313 (0.02) 0.1210313) 
graph save "Tax_AvAuthoritative_fv.gph", replace

*Authoritarian
twoway (scatter average_an average_MRP, color(black) mlabcolor(black)  mlabel(country) mlabsize(vsmall) mlabposition(1)) (lfit average_an average_MRP, color(black)), ///
legend(off) xtitle("Tax Progressivity (USA=1)") ytitle("Authoritarian parents (%)")  ///
ylabel(5 (10) 85) xscale(r(0.03 0.12)) graphregion(color(white)) xticks(0.0410313 (0.02) 0.1210313) xlabel(none) // xlabel(0.0410313 (0.02) 0.1210313) 
graph save "Tax_AvAuthoritarian_fv.gph", replace

* Combine Graphs
graph combine "Tax_AvPermissive_fv.gph" "Tax_AvAuthoritative_fv.gph" "Tax_AvAuthoritarian_fv.gph", ///
 rows(1) altshrink ysize(5) xsize(15) graphregion(color(white)) saving("Figure3_4_fv.gph",replace)

* Note: For rescaling of the X-axis just set (with graph editor US=1 and move with respect to the tags of of 0.2 for each tag)
 
 
 
*



