* Figure 3.6
clear all
set more off

use WVS_ED, clear // World value survey, wave 5 only, with World Bank education data

*Returns to schooling are returns to tertiary education (Montenegro and Patrinos, 2014)

/* The PERMISSIVE, AUTHORITATIVE, AUTHORITARIAN variables were generated from
the question asking parent to praise obedience, imagination, hark work, independence
*PERMISSIVE: Praising Imagination or Independe (or both), No Hard Work No Obedience 
*AUTHORITATIVE: Praising Hard Work, No Obedience
*AUTHORITARIAN: Praising Obedience
*/

*RETURN TO SCHOOLING
*Excluded Switzerland, New Zealand, Finland, UK (NO DATA ABOUT RETURNS TO TERTIARY EDUCATION)

* Calculate means of each variable  by country-year-wave
collapse permissive authoritative authoritarian returns_tert yreturns_tert year, by(country wave country3l_wave)

* multiply by 100 to have percentage

replace permissive=100*permissive
replace authoritative=100*authoritative
replace authoritarian=100*authoritarian

*Final version
twoway (scatter permissive returns_tert, mlabel(country) mlabsize(vsmall) mlabposition(1) color(black) mlabcol(black)) (lfit permissive returns_tert, lc(gray)), ///
legend(off) xtitle("Annual Return to University/Post-Graduate Education (%)", size(small)) ytitle("Permissive Parents (%)") ///
yscale(range(5 80))  ylabel(5 (15) 80) xscale(range(6 17.5)) xlabel(6 (2) 17) graphregion(fcolor(white)) 
graph save "Educ_Permissive_fv.gph", replace 

*Final version
twoway (scatter authoritative returns, mlabel(country) mlabsize(vsmall) mlabposition(1) color(black) mlabcol(black)) (lfit authoritative returns, lc(gray)), ///
legend(off) xtitle("Annual Return to University/Post-Graduate Education (%)", size(small)) ytitle("Authoritative Parents (%)") ///
yscale(range(5 80))  ylabel(5 (15) 80) xscale(range(6 17.5)) xlabel(6 (2) 17) graphregion(fcolor(white)) 
graph save "Educ_Authoritative_fv.gph", replace 

*Final version
twoway (scatter authoritarian returns, mlabel(country) mlabsize(vsmall) mlabposition(1) color(black) mlabcol(black)) (lfit authoritarian returns, lc(gray)) , ///
legend(off) xtitle("Annual Return to University/Post-Graduate Education (%)", size(small)) ytitle("Authoritarian Parents (%)") ///
yscale(range(5 80))  ylabel(5 (15) 80) xscale(range(6 17.5)) xlabel(6 (2) 17) graphregion(fcolor(white))  
graph save "Educ_Authoritarian_fv.gph", replace 

*Final version, combine
graph combine "Educ_Permissive_fv.gph" "Educ_Authoritative_fv.gph" "Educ_Authoritarian_fv.gph" , rows(1) altshrink graphregion(fcolor(white))  ///
ysize(5) xsize(15) saving("Figure3_6_fv.gph",replace)
